Kartik Arora Topsis 101917070
Used Formula: Eucledian Distance
Output: Result File:
Use on command Window
Installation: pip install Topsis-Kartik-101917070

License
© 2020 Udit Vashisht
This repository is licensed under the MIT license. See LICENSE for details.